==> indicator-application_0.3.2.orig.tar.gz: indicator-application-0.3.2/src/gen-application-service.xml.c <==
const char * _application_service = 
"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
"<!--\n"
"An interface for communication between the service and indicator.\n"
"\n"
"Copyright 2009 Canonical Ltd.\n"
"\n"
"Authors:\n"
"    Ted Gould <ted@canonical.com>\n"
"\n"
"This program is free software: you can redistribute it and/or modify it \n"
"under the terms of the GNU General Public License version 3, as published \n"
"by the Free Software Foundation.\n"
"\n"
"This program is distributed in the hope that it will be useful, but \n"
"WITHOUT ANY WARRANTY; without even the implied warranties of \n"
"MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR \n"
"PURPOSE.  See the GNU General Public License for more details.\n"
"\n"
"You should have received a copy of the GNU General Public License along \n"
"with this program.  If not, see <http://www.gnu.org/licenses/>.\n"
"-->\n"
"<node name=\"/\">\n"
"	<interface name=\"com.canonical.indicator.application.service\">\n"
"<!-- Properties -->\n"
"		<!-- None currently -->\n"
"\n"
"<!-- Methods -->\n"
"		<method name=\"GetApplications\">\n"
"			<arg type=\"a(sisossss)\" name=\"applications\" direction=\"out\" />\n"
"		</method>\n"
"		<method name=\"ApplicationScrollEvent\">\n"
"			<arg type=\"s\" name=\"dbusaddress\" direction=\"in\" />\n"
"			<arg type=\"s\" name=\"dbusobject\" direction=\"in\" />\n"
"			<arg type=\"i\" name=\"delta\" direction=\"in\" />\n"
"			<arg type=\"u\" name=\"direction\" direction=\"in\" />\n"
"		</method>\n"
"\n"
"<!-- Signals -->\n"
"		<signal name=\"ApplicationAdded\">\n"
"			<arg type=\"s\" name=\"iconname\" direction=\"out\" />\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"dbusaddress\" direction=\"out\" />\n"
"			<arg type=\"o\" name=\"dbusobject\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"iconpath\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"label\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"labelguide\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"accessibledesc\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationRemoved\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationIconChanged\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"icon_name\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"icon_desc\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationIconThemePathChanged\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"icon_theme_path\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationLabelChanged\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"label\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"guide\" direction=\"out\" />\n"
"		</signal>\n"
"	</interface>\n"
"</node>\n"
;

==> indicator-application_0.4.0.orig.tar.gz: indicator-application-0.4.0/src/gen-application-service.xml.c <==
const char * _application_service = 
"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
"<!--\n"
"An interface for communication between the service and indicator.\n"
"\n"
"Copyright 2009 Canonical Ltd.\n"
"\n"
"Authors:\n"
"    Ted Gould <ted@canonical.com>\n"
"\n"
"This program is free software: you can redistribute it and/or modify it \n"
"under the terms of the GNU General Public License version 3, as published \n"
"by the Free Software Foundation.\n"
"\n"
"This program is distributed in the hope that it will be useful, but \n"
"WITHOUT ANY WARRANTY; without even the implied warranties of \n"
"MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR \n"
"PURPOSE.  See the GNU General Public License for more details.\n"
"\n"
"You should have received a copy of the GNU General Public License along \n"
"with this program.  If not, see <http://www.gnu.org/licenses/>.\n"
"-->\n"
"<node name=\"/\">\n"
"	<interface name=\"com.canonical.indicator.application.service\">\n"
"<!-- Properties -->\n"
"		<!-- None currently -->\n"
"\n"
"<!-- Methods -->\n"
"		<method name=\"GetApplications\">\n"
"			<arg type=\"a(sisosssss)\" name=\"applications\" direction=\"out\" />\n"
"		</method>\n"
"		<method name=\"ApplicationScrollEvent\">\n"
"			<arg type=\"s\" name=\"dbusaddress\" direction=\"in\" />\n"
"			<arg type=\"s\" name=\"dbusobject\" direction=\"in\" />\n"
"			<arg type=\"i\" name=\"delta\" direction=\"in\" />\n"
"			<arg type=\"u\" name=\"direction\" direction=\"in\" />\n"
"		</method>\n"
"		<method name=\"ApplicationSecondaryActivateEvent\">\n"
"			<arg type=\"s\" name=\"dbusaddress\" direction=\"in\" />\n"
"			<arg type=\"s\" name=\"dbusobject\" direction=\"in\" />\n"
"			<arg type=\"u\" name=\"time\" direction=\"in\" />\n"
"		</method>\n"
"\n"
"<!-- Signals -->\n"
"		<signal name=\"ApplicationAdded\">\n"
"			<arg type=\"s\" name=\"iconname\" direction=\"out\" />\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"dbusaddress\" direction=\"out\" />\n"
"			<arg type=\"o\" name=\"dbusobject\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"iconpath\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"label\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"labelguide\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"accessibledesc\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"hint\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationRemoved\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationIconChanged\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"icon_name\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"icon_desc\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationIconThemePathChanged\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"icon_theme_path\" direction=\"out\" />\n"
"		</signal>\n"
"		<signal name=\"ApplicationLabelChanged\">\n"
"			<arg type=\"i\" name=\"position\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"label\" direction=\"out\" />\n"
"			<arg type=\"s\" name=\"guide\" direction=\"out\" />\n"
"		</signal>\n"
"	</interface>\n"
"</node>\n"
;
